@@ -55,11 +55,11 @@ pub(crate) struct Node {
 /// Differentiable variable. This is the main type that users will interact with.
 pub struct Var<'a> {
     /// Value of the variable.
-    val: f64,
+    pub val: f64,
     /// Location that can be referred to be nodes in the tape.
     location: usize,
     /// Reference to a tape that this variable is associated with.
-    tape: &'a Tape,
+    pub tape: &'a Tape,
 }
 
 #[derive(Debug, Clone)]
@@ -422,6 +422,18 @@ impl<'a> PartialOrd<f64> for Var<'a> {
     }
 }
 
+impl<'a> PartialEq<Var<'a>> for f64 {
+    fn eq(&self, other: &Var<'a>) -> bool {
+        other.val.eq(self)
+    }
+}
+
+impl<'a> PartialOrd<Var<'a>> for f64 {
+    fn partial_cmp(&self, other: &Var<'a>) -> Option<std::cmp::Ordering> {
+        other.val.partial_cmp(self)
+    }
+}
+
 /// Calculate gradients with respect to particular variables.
 pub trait Gradient<T, S> {
     /// Calculate the gradient with respect to variable(s) `v`.
